package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H"(``#0````PP0```````#0`(``,
M`"@`&P`:``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````V!$`
M`-@1```$`````!````$`````(````"`````@``"<,0``G#$```4`````$```
M`0````!@````8````&```.1.``#D3@``!``````0```!````U+T``-2]``#4
MO0``1`(``%@"```&`````!````(```#<O0``W+T``-R]```(`0``"`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&1PH```<*```'"@```<`0``
M'`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DU+T``-2]``#4O0``+`(``"P"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`#H62R*MJEW;ST#YX8'@HR[=+RF*!```
M`!@````%````1TY5``$``<`$`````0````(``<`$``````````0````0````
M`0```$=.50``````!`````0`````````*P```$4````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(10``````````````1@``````
M````````1P````````!(````20````````!*`````````$P`````````````
M`$T```!.`````````%````!1````4P````````!4````50```%8`````````
M`````````````````````%<```!8````60```%H```!;``````````````!=
M`````````%X``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````"O`@`````````````2````Q@(`````````````$@```,`"````
M`````````!(````9`0`````````````2````8P$`````````````$@```.(`
M`````````````!(````]`@`````````````2````+P(`````````````$@``
M`/@``````````````!(````!```````````````@````#`(`````````````
M$@```*P!`````````````!(```#7`@`````````````2````F@``````````
M````$@```,,``````````````!(````R`0`````````````2````%`(`````
M````````$@```-H!`````````````!(````0```````````````@````[0``
M````````````$@```!X!`````````````!(```#N`0`````````````2````
M+```````````````(````),"`````````````!(```!S`@`````````````2
M````]0$`````````````$@```$`!`````````````!(```""`0``````````
M```6````B@``````````````$@```$8``````````````!(```"R````````
M```````2````HP``````````````$@```&D"`````````````!(```""`@``
M```````````1````F@(`````````````$@```%("`````````````!(````H
M`@`````````````2````E@,`````````````$@```",!`````````````!(`
M``#G`0`````````````2````SP(`````````````$0```(D"````````````
M`!(````+`0`````````````2````2P(`````````````$@```'L!````````
M`````!(```!7```````````````2````Z0(`````````````$@```+L!````
M`````````!(````A`@`````````````2````D@(`````````````$@```&`"
M`````````````!(```"D`0`````````````2````3@$`````````````$@``
M`&\!`````````````!(```"A`@`````````````2````S0(`````````````
M$0```%D"`````````````!(```#?`0`````````````2````;@``````````
M````$0```-,``````````````!$```!C```````````````2````>P``````
M````````$@```$0"`````````````!(```#!`0`````````````2````LP$`
M````````````$@```-,!`````````````!(```#]`0`````````````B````
M'`(`````````````$@```!@$```4P```!````!$`%P!Z`P``,$\``!`"```2
M``X`*@0``%`O``#\`P``$@`.`"($``#`,P``-0```!(`#@`@`P``D"T``#@`
M```2``X`;@,``-`M``!T`0``$@`.`/(#```8P````````!``%P#@`P``+,``
M```````0`!@`2@,``%`S``!A````$@`.`"T#````8```!````!$`$`"?`P``
M,$```-$````2``X`UP,```!-``!0````$@`.``\#``!0*P``!0```!(`#@"K
M`P```,`````````0`!<`"P0``&`K```G`@``$@`.`/D#``#`-0``^0```!(`
M#@##`P``0"H``#0````2``X`K0,```#`````````(``7`.4#``#`-@``2@<`
M`!(`#@#+`P``&,`````````0`!@`A`,``)`U```M````$@`.`%@#``"`*@``
MS0```!(`#@"X`P``4$T``-<!```2``X`S@$``$`@``!5`@``$@`.`+$#``"@
M(@``+````!(`#@`T`P``$#X``!X"```2``X`E0$```1@```$````$0`0``!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!097)L7V%T9F]R:U]L;V-K`%!E<FQ?
M;6=?<V5T`%!E<FQ?;F5W6%,`4$Q?9&]?=6YD=6UP`%!E<FQ?<WES7VEN:70S
M`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L7V-O;G-T<G5C=`!097)L
M7VYE=UA37V9L86=S`%!E<FQ?9W9?9F5T8VAP=@!03%]M96UO<GE?=W)A<`!P
M97)L7W!A<G-E`'!E<FQ?86QL;V,`4&5R;%]A=&9O<FM?=6YL;V-K`'!E<FQ?
M9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]S>7-?=&5R;0!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V=E
M=%]S=@!097)L7W-A9F5S>7-M86QL;V,`4$Q?8W5R<F5N=%]C;VYT97AT`%])
M3U]S=&1I;E]U<V5D`&UE;6UO=F4`<W1R8VAR`&QS965K-C0`<FUD:7(`7U]L
M:6)C7W-T87)T7VUA:6X`<W1R8VUP`')E860`<W1R;F-M<`!G971U:60`86-C
M97-S`&]P96YD:7(`7U]C>&%?9FEN86QI>F4`<F5A;&QO8P!S=')R8VAR`&5X
M:70`<W1R=&]K`'5N;&EN:P!?7V9P<FEN=&9?8VAK`&]P96XV-`!S=')D=7``
M<W1R<W1R`'-T<FQE;@!M96UC:'(`<F5A9&QI;FL`<F5A9&1I<C8T`%]?=F9P
M<FEN=&9?8VAK`'-T9&5R<@!C;&]S961I<@!L<W1A=#8T`&UE;6-P>0!?7W-P
M<FEN=&9?8VAK`%]?97)R;F]?;&]C871I;VX`;6MD:7(`9V5T<&ED`%]?96YV
M:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`&QI8G!E
M<FPN<V\`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE
M`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S
M=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`
M7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A
M<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)
M0D-?,BXQ+C,`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXR`$=,24)#
M7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ`$=,24)#
M7S(N,``O=7-R+VQI8B]P97)L-2\U+C,X+V-O<F5?<&5R;"]#3U)%`````@`"
M``(``0`!``$``P`$``$``0`"``(`!0`!``$``0`"``(``0`!``(``@`!``8`
M!``"``$``0`!``$``0`!``<``@`"``(``@`"``$``@`"``(``0`"``(``0`(
M``(``@`&``(``@`!``$`!``"``(``@`!``$``0`!``(`"0`#``(`"@`"``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$`"0`%`P``$`````````!S'VD)```*`#<$```0````M)&6!@``
M"0!#!```$````!1I:0T```@`3@0``!`````2:6D-```'`%@$```0````LY&6
M!@``!@!B!```$````'(9:0D```4`;00``!````!T&6D)```$`'D$```0````
M$6EI#0```P"%!```$````!!I:0T```(`CP0```````#4O0``"````-B]```(
M````_+\```@````$P```"````!3````(````]+X```8!``#XO@``!@(``/R^
M```&`P```+\```8$```$OP``!@4```B_```&!@``#+\```8'```0OP``!@@`
M`!2_```&"0``&+\```8*```<OP``!@L``""_```&#```)+\```8-```HOP``
M!@X``"R_```&#P``,+\```80```TOP``!A$``#B_```&$@``/+\```83``!`
MOP``!A0``$2_```&%0``2+\```86``!,OP``!A<``%"_```&&```5+\```89
M``!8OP``!AH``%R_```&&P``8+\```X<``!DOP``!AT``&B_```&'@``;+\`
M``8?``!POP``!B```'2_```&(0``>+\```8B``!\OP``!B,``("_```&)```
MA+\```8E``"(OP``!B8``(R_```&)P``D+\```8H``"4OP``!BD``)B_```&
M*@``G+\```8K``"@OP``!BP``*2_```&+0``J+\```8N``"LOP``!B\``+"_
M```&,```M+\```8Q``"XOP``!C(``+R_```&,P``P+\```8T``#$OP``!C4`
M`,B_```&-@``S+\```8W``#0OP``!CD``-2_```&.@``V+\```8[``#<OP``
M!CP``."_```&/0``Y+\```8^``#HOP``!C\``.R_```&00``\+\```9"``#T
MOP``!D,``/B_```&1```\+X```=`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z,<"``"!P]N>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z'D"``"!
MPXV>``!1@^PLBT$$B474BT$(B4709:$4````B47D,<"-1=!0C4744%'_DP`!
M``"+@S````"#Q`Q04/^SA````&?HHC```(N#]````(/$$(`X``^$)0$``(N#
M?````&6+`("(H@(```.+!XUP`X/`!(EUS#W___\_#X>$`0``@^P,P>`"4/^3
MY````(MUU(L_B<&)@T`!``"+!H/$$(D!C8,'H___B4$$BX,P`0``B4$(C8,*
MH___B4$,@_\!#XY@`0``B4W(C48$C5$0C32^C;0F`````&:0BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8/\:O__QP2Y`````&H`4?]US%#_LT0!``#_DR0`
M``"#Q""%P`^$F````(/L#/^S1`$``(U]X/^3N````(GZB<:-@\.A___H/`(`
M`(/$$(7`#X2#````@^P,_[-$`0``_Y,<````@\00_Y-X````BT7D92L%%```
M``^%R0```(UE\(GP65M>7UV-8?S#_Y-<````B8-$`0``A<`/A)P```"#[`Q0
M_Y.,````BX-\````98L0@\00QH)R!0```.FK_O__@^P,_[-$`0``_Y-$````
M@\00Z5'___^+@SP!``"%P'01@^P,4.C['0``@\00Z6+___^)^HV#>*'__^B&
M`0``B8,\`0``A<`/A$?____KTHM%Y&4K!10```!U*E!0C8-SH?___[/X````
M4/^3X````+\$````Z<#^__^#[`QJ`?^3%`$``.C;+@``9I!FD&:09I!FD)`Q
M[5Z)X8/D\%!44N@8````@<,TG```:@!J`%%6_[,8`0``Z&G]___TBQPDPV:0
M9I"+'"3#9I!FD&:09I!FD&:0Z.````"!PO^;``"-BC0!``"-@C0!```YR'0=
MBX)8````A<!T$U6)Y8/L%%'_T(/$$,G#C70F`)##C;0F`````.B@````@<*_
MFP``58GE4XV*-`$``(V"-`$``(/L!"G(B</!Z!_!^P(!V-'X=!2+DF@```"%
MTG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:058GE4^A7____@<-KFP``@^P$
M@+LT`0```'4HBX,0`0``A<!T$H/L#/^S(`$``/^3$`$``(/$$.@T____QH,T
M`0```8M=_,G#C;0F`````)#I6____XL4),-FD&:09I"05>@W'0``@<4.FP``
M5U93@^P<B50D"(7`#X2R````B<&+A;````"+$(72#X2@````#[8!A,!T!#P]
M=54Q_XL:A=MT/8E4)`R)V(G3B4PD!(G&C;0F`````(/L!%?_="0,5O^5\```
M`(/$$(7`=0:`/#X]=#2+<P2#PP2%]G7:B?.#Q!R)V%M>7UW#C;8`````B<\/
MMD<!@\<!A,!T!#P]=?$IS^N8C78`BU0D#(GPB=Z)PXM$)`@IUHU<.P'!_@*)
M,(/$'(G86UY?7<.-="8`D(/$'#';B=A;7E]=PXUT)@!6Z$\<``"!QBZ:``!3
MB<.#['QEH10```")1"1T,<"-1"044%/_EM0```"#Q!"%P'4WBU0D'('B`/``
M`('Z`$```'0(@?H`H```=1^#[`AJ`E/_EF0```"#Q!"%P`^4P`^VP.L&C70F
M`#'`BU0D;&4K%10```!U!H/$=%M>P^@^+```C;0F`````(VT)@````!55U;H
MO1L``('&G)D``%.)PX'LC````&6A%````(E$)'PQP(7;=`6`.P!U)(M$)'QE
M*P44````#X4\`0``@<2,````6UY?7<.-M"8`````D(/L#%/_EG0```")QX/$
M$(7`=,F#[`Q7_Y:0````@\00A<`/A+@```"`>!,NC5`3=0^`>@$`=-R-M"8`
M````9I"`>!,N#X2V````B50D#(/L#%/_EIP```"+5"0<B<6)%"2)5"0<_Y:<
M````C40%`HD$)/^6P````(G%6(V&)*'__UJ+5"044E-0:O]J`57_EN@```"#
MQ!B-1"0D4%7_EFP```"#Q!"#^/]T$(M$)"PE`/```#T`0```=&6#[`Q5_Y:@
M````@\00@^P,5?^68````(/$$.DY____C;8`````@^P,5_^6M````(D<)/^6
MS````(/$$.GA_O__C70F`)"`>@$N#X5`____@'H"``^$__[__^DQ____C;0F
M`````(GHZ(G^___KG^BR*@``9I!5Z$<:``"!Q1Z8``!7B<=64XG3@^PX9:$4
M````B40D*#'`,<"`.CT/E,`!PU/_E9P```"#Q!")1"0$B?B-5"08Z,O\__^%
MP`^$$P$``(/L#(G&4/^5G````(M,)!2#Q!`YR`^#V````(M$)!C!X`*)1"0(
MBX6P````B00D#[8'A,`/A*D!```\/0^$H0$``(GXC;0F``````^V4`&#P`&$
MTG0%@/H]=?`I^(L,)(MT)`B#[`R+5"00`S&-1!`"4/^5P````(D&@\00A<!T
M48L,)(MT)`B+`8U/`8L4,`^V!X@"/#UT'83`=0KK%XUT)@`\/70/#[8!@\(!
M@\$!B`*$P'7MQ@(],<"-M"8`````D`^V#`.(3`(!@\`!A,EU\8M$)!QE*P44
M````#X43`0``@\0L6UY?7<.-M"8`````D#'`C;8`````#[84`X@4!H/``832
M=?+KQXVT)@````"0BX6P````BQ")!"2+,H7V#X3"````,?:-M"8`````9I")
M\(/&`8L,LH7)=?2-!(4,````BXTX`0``A<EU8XE4)`R#[`Q0QX4X`0```0``
M`/^5P````(G!@\00A<`/A%W___^-!+4`````@^P$B40D#%"+5"044E&)3"0<
M_Y7<````BT0D$(M,)!R#Q!")",=$L00`````B70D&.E]_O__D(/L"%!2_Y4X
M````B<&+1"00@\00B0B%R0^$`?___XT$M0````")1"0(Z\.-="8`D#'`Z7/^
M__^X"````#'VZ5#____H:"@``(VT)@````"055=64X'L`!```(,,)`"#[##H
MXQ<``(''OI4``(E4)!")QF6A%````(F$)"`0```QP&C_#P``C8<JH?__C6PD
M)%50_Y?8````@\00A<!^$(G#C4#_@'P<&P!U187`=3F+AWP```"#[`3_="00
M5F7_,/^73````(/$$(N$)!P0``!E*P44````=4*!Q"P0``!;7E]=PXUT)@")
MPXVV`````(/L!%-J+U7_E^P```"#Q!"%P'2KBX=\````4U569?\P_Y>H````
M@\00ZZ[HD"<``%93Z.GX__^!P_V4``"#[`2-@X#A__^+LWP```!0C8,YH?__
M_[.`````4&7_-O^3_````%B-@^2B__]::@!04(V#+'___U"-@U6A__]09?\V
M_Y.(````@\0D6U[#C70F`.B\%@``!9^4``"#[`R-D(#A__]2C9`YH?___["`
M````4HN0?````&7_,O^0_````(/$',.-M"8`````C70F`)!55U93@>P`$```
M@PPD`('L`!```(,,)`"#[!PQ[>@N^/__@<-"E```9:$4````B80D#"```#'`
M_Y,4````@^P(C9,UH?__4E"-@VJA__]0:`$0``!J`8UT)"96_Y/H````@\0<
M:``0``"-O"03$```5U;_D]@```"#Q!"%P'@L@^P,B<:-0`%0_Y/`````B<6#
MQ!"%P'04@^P$5E=0_Y.8````QD0U``"#Q!"+A"0,(```92L%%````'4-@<0<
M(```B>A;7E]=P^@C)@``C78`Z2O___^-M"8`````C70F`%575E.![``0``"#
M#"0`@>R<````Z%?W__^!PVN3``"+O"2P$```BZPDM!```&6A%````(F$)(P0
M```QP(U$)"R)1"04B<*-@WBA___H'_C__X/L"&HOB<97_Y,\````@\00A<!T
M,HV#@:'__XGZZ.WZ__^)^(N4)(P0``!E*Q44````#X69`0``@<2<$```6UY?
M7<.-="8`@^P,5?^3!`$``%I9C8N.H?__B4PD%%%0_Y/0````C8N0H?__B<6-
M@YFB__^#Q!")1"08A>UTEX!]``")3"0<#X3J````C78`A?9T%H/L"%56_Y,,
M`0``@\00A<`/A*<```"#[`Q5_Y.<````B<*-1`7_@\00.<5R$>LCC70F`)#&
M``"#Z`$YQ70%@#@O=/&#[`Q5_Y.<````B<*#Q!")5"00@^P,5_^3G````(M4
M)""-1`(!@\00/?\/```/APS___^#[`17_W0D)%7_="0H:``0``!J`8VL)*@`
M``!5_Y/H````@\08_W0D'%7_DVP```"#Q!"%P'40BT0D/"4`\```/0"```!T
M3X/L"/]T)!1J`/^3T````(G%@\00A<`/A*G^__^`?0``#X49____A?9T!8`^
M+G00N@$```"-JW:A___I5O___X!^`0!TN^OHC;0F`````)"#[`AJ`57_DV0`
M``"#Q!"%P'6>B>J-@X&A___H4/G__X/L#%7_DP0!``"#Q!#I4_[__^CI(P``
MC;0F`````&:05NAO$P``@<9.D0``4X/L#(M<)!AJ+U/_EE````"#Q!"%P'0#
MC5@!B5PD$(/$!(GP6U[_H`0!``"-M"8`````D%575E.![``0``"##"0`@^P<
MZ"<3``"!Q?Z0``"+M"0P$```9:$4````B80D#!```#'`A?8/A*8```"`/@`/
MA)T```"#[`Q6_Y6<````C4@!@\00@?D`$```#X?A````C5PD#(/Y!`^#I```
M`(7)#X7<````C40#_SG#<@[K$6:0Q@``@^@!.=AT!8`X+W3Q@^P(:B]3_Y50
M````@\00A<!T/CG##X*&````@^P,4_^5!`$``(/$$(N4)`P0``!E*Q44````
M#X6D````@<0<$```6UY?7<.-M"8`````C78`BX0D#!```&4K!10```!U?XV%
M=J'__XF$)#`0``"!Q!P0``")Z%M>7UW_H`0!``"0BU0._(G?B50,"(G!P>D"
M\Z7I3O___XVT)@````"-=@#&``#I<O___XVT)@````"0,<#I</___XVT)@``
M``!FD`^V%HA4)`SVP0(/A!3___\/MU0._F:)5`P*Z07____H+"(``(VT)@``
M``"-="8`D%575NBM$0``@<:,CP``4X/L+&6A%````(E$)!PQP(U<)!B+KK``
M``"-OI*A__^)VHGXZ$GT__^%P'0NBU0D&(M%`(T$D(M0!(D0A=)TX&:0BU`(
M@\`$B1"%TG7TB=J)^.@;]/__A<!UTHNNL````(V^FZ'__XG:B?CH`O3__X7`
M="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.C3\___
MA<!UT8NNL````(V^HZ'__XG:B?CHNO/__X7`="^+5"08BT4`C020BU`$B1"%
MTG3@C78`BU`(@\`$B1"%TG7TB=J)^.B+\___A<!UT8NNL````(V^K*'__XG:
MB?CH<O/__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7T
MB=J)^.A#\___A<!UT8V&LZ'__XN^L````(D$)(L$)(G:Z";S__^%P'0LBU0D
M&(L'C020BU`$B1"%TG3@BU`(@\`$B1"%TG7TBP0DB=KH^O+__X7`==2+KK``
M``"-OL.A__^)VHGXZ.'R__^%P'0VBU0D&(M%`(T$D(M0!(D0A=)TX(VT)@``
M``"-=@"+4`B#P`2)$(72=?2)VHGXZ*OR__^%P'7*C89XH?__B[ZP````B40D
M!(M$)`2)VNB,\O__A<!T,XM4)!B+!XT$D(M0!(D0A=)TWXVV`````(M0"(/`
M!(D0A=)U](M$)`2)VNA9\O__A<!US8V&SZ'__XN^L````(E$)`R+1"0,B=KH
M.O+__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-="8`BU`(@\`$B1"%TG7TBT0D
M#(G:Z`GR__^%P'7/C8;9H?__B[ZP````B40D"(M$)`B)VNCJ\?__A<!T,8M4
M)!B+!XT$D(M0!(D0A=)TWXUT)@"+4`B#P`2)$(72=?2+1"0(B=KHN?'__X7`
M=<^+KK````"-ON.A__^)VHGXZ*#Q__^%P'0UBU0D&(M%`(T$D(M0!(D0A=)T
MX(VT)@````!FD(M0"(/`!(D0A=)U](G:B?CH:_'__X7`=<N+KK````"-OH&A
M__^)VHGXZ%+Q__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0
MA=)U](G:B?CH(_'__X7`==&)VHV&[:'__^@2\?__A<!T"XG"BT0D".CS\___
MB=J-AOZA___H]O#__X7`=`V)PHV&$*+__^C5\___B=J-AANB___HV/#__XG"
MA<!T*XM$)`3HN?/__XM$)!QE*P44````=3.+!"2#Q"R-ECRB__];7E]=Z9?S
M__^)VHV&*Z+__^B:\/__A<!TS8G"BT0D#.A[\___Z\#H)!X``(UT)@#HK`T`
M``6/BP``@^P<98L5%````(E4)`PQTHU4)`B-@,^A___H5_#__X7`="L/MA"`
M^C`/E,"$T@^4P@G0@_`!#[;`BU0D#&4K%10```!U#(/$',.-="8`,<#KY^B_
M'0``C;0F`````(VT)@````"04^@*[___@<,>BP``@^P(C40D%%#_="04BX.4
M````:@'_,/^3<````,<$)/\```#_DQ0!``"-M"8`````C70F`%575E.-G"0`
M`/__@>P`$```@PPD`#G<=?*#["SHK^[__X'#PXH``(E$)`2)QV6A%````(F$
M)!P``0`QP&H":@!J`%?_DP@!``"#P/^#TO^)1"08B=>)5"0<P?\?B?XQ\"GP
M,=(E__\``#'Z,?`I\(MT)!@9^HM\)!PIQAG7@\00C6PD%(7_#XBP````C70F
M`&H`5U;_="00_Y,(`0``(="#Q!"#^/\/A+L```"#[`1H"``!`%7_="00_Y-4
M````@\00@_C_#X1]````@_@'=E"-1`7X.>AR2(T5)`$``.L'@^@!.>AR.8L,
M&CD(=?*+BR@!```Y2`1UYRGHF0'P$?J+C"0<``$`92L-%````'5V@<0L``$`
M6UY?7<.-="8`D('&``#__X/7_XGPB?HU``#___?2"=`/A53___^X_____[K_
M____Z[B+A"0<``$`92L%%````'4N@^P,C8-+HO__4.A9_O__BX0D'``!`&4K
M!10```!U#X/L#(V#/J+__U#H.O[__^CE&P``C70F`)!3Z#KM__^!PTZ)``"#
M[`C_DZP```"#[`Q0_Y.D````@\00A<!T`HL`@\0(6\.-=@!55U;H/0L``('&
M'(D``%.#["QEH10```")1"0<,<"-5"08BVPD0(V^5Z+__XGXZ-WM__^%P'0'
M@#@`B<-U(HM$)!QE*P44````#X6E````B>J#Q"R)^%M>7UWIH?#__Y"#[`A5
M4/^6O````(/$$(7`=!Z+1"0<92L%%````'5U@\0L6UY?7<.-M"8`````9I"#
M[`Q5_Y:<````B40D'(D<)/^6G````(M4)!R-1`("B00D_Y;`````@\0,B<*-
MAHZA__]34(V&F:+__U50:O]J`5*)5"0L_Y;H````@\0@BU0D#(M$)!QE*P44
M````#X1=____Z+<:``"-M"8`````55=64^@'[/__@<,;B```@>S\````BX0D
M$`$``(U\)"R)^HE$)`QEH10```")A"3L````,<"-@VZB___'A"24````````
M`(F$)(P```"-@W:A__^)A"20````C8,)HO__B80DJ````(V#<Z+__XF$)*P`
M``"-@R:B__^)A"2P````C8-[HO__B80DM````(V#?Z+__XF$))@```"-@X2B
M__^)A"2<````C8-XH?__QX0DN`````````#'A"2@`````````(E$)!CH0^S_
M_X7`=`N`.`")Q@^%C`0``/^3K````(/L#%#_DZ0```"#Q!"%P`^$V0,``(LH
MA>T/A,\#``"#[`Q5_Y.<````C40``8/$$(/L#%#_D\````")Q@^V10"#Q!")
M="0(A,!T.XV+C:+__XE\)`2)]XG.C70F`)"#[`P/ML"#Q0%05FK_:@%7@\<"
M_Y/H````#[9%`(/$((3`==R+?"0$C;0DI````(V#$*+__^L3C;0F`````&:0
MBT8$@\8$A<!T-HGZZ'_K__^)Q87`=.F`.`!TY.A/[/__A<!TVX/L#%7_DP0!
M``")Q8/$$(7`=3B-M"8`````D(VT)(P```"++H7M=".`?0``#X3Q`@``B>CH
M$NS__X7`#X7R````BVX$@\8$A>UUW8/L#%7_DYP```!:_W0D%(G&_Y.<````
MC;0&!`0``(DT)/^3P````(E$)!2)P8V#DJ+___]T)!A0C8.0H?__B40D(%"-
M@Y>B__]5B<U0:O]J`5'_D^@```"#Q"AHP`$``%7_DQ@```"#Q!"#^/]U$?^3
M$````(L`@_@1#X78`@``@^P(5_]T)!#_D]0```")Q8/$$(7`='F#[`S_="00
MBT0D'/\PC8-,H___4#'VBX.4````:@'_,/^3+````(/$((N$).P```!E*P44
M````#X5B!```@<3\````B?!;7E]=PXVT)@````"#[`R#Q@15_Y,$`0``B<6#
MQ!"%P`^$U?[__^GY_O__C;0F`````&:0BT0D/"4`\```/0!````/A7/___^+
M1"1$B40D$/^3K````#E$)!`/A5O___^+1"0\)?\!```]P`$```^%1____X/L
M#%;_D\````")^HG&C8-BHO__Z+?I__^#Q!"%P`^$1`(``(/L"%"+1"08_S#H
M+?'__XE$)""#Q!"%P`^$)@(``(/L#/]T)!S_DYP```")PH/$$(/X`W9'@^P(
MC8.@HO__4(M$)!R-1!#\B50D*%#_DPP!``"#Q!"%P'4CBU0D'(/Z!`^$`@,`
M`(M$)!"`?!#[+P^$\P(``(VT)@````")^HV[SZ'__XGXZ"'I__^%P`^$R0$`
M``^V`(3`#X2^`0``/#`/A+8!``"-DSRB__^)^(V[Y*+__^CCZ____Y,4````
M5U"-@\2B____="00_W0D$%!J_VH!5O^3Z````(V#TJ+__X/$((E$)`SK-F:0
M_Y,0````@S@1=4#_DQ0```"#Q0&#[`Q755#_="0@_W0D(/]T)"QJ_VH!5O^3
MZ````(/$,(/L"&C``0``5O^3&````(/$$(/X_W2U@^P,_W0D$/^38````(M$
M)"B)\NA-Z___B30DZ$7Z__^#Q!#I[?W__XUT)@"0,>WI(?W__Y"+A"28````
MC;0DF````(7`=""-M@````")^N@AZ/__A<!T!8`X`'4XBT8$@\8$A<!UYH/L
M#(VK9Z+__VH-_Y/`````B<:#Q!")1"0(N%,```#I!_S__XVT)@````"-=@"#
M[`Q0_Y,$`0``B<6#Q!"%P'2UZ;G[__^#[`A0_W0D$(M$)!S_,(V#$*/__^DY
M_?__C;0F`````(/L#%#HC_G__X/$$(N$).P```!E*P44````#X6>`0``B;0D
M$`$``('$_````(G86UY?7?^@!`$``(VT)@````"+1"0,BP")1"00Z<O]__^-
MM"8`````9I"#[`AJ`/]T)!S_DR@```"#Q!"%P`^$,/[__XE$)`SH7??__XE$
M)!")5"04A=(/B!?^__^#P/9J`(/2_U)0BTPD&%&)3"0<_Y,(`0``@\0,:@:-
MA"3%````4(M,)!A1B4PD'/^35````(/$$(M,)`R#^`8/A?,```"!O"2]````
M`$-!0P^%P?W__V:!O"3!````2$4/A;']__]J`(M$)!2+5"08@\#.@]+_4E!1
MB4PD'/^3"`$``(/$#&HHC;PDRP```%>+3"084?^35````(/$$(/X*`^%D0``
M`(V#Y*+__\:$).L`````4(V#M:+__U?_="00_W0D$%!J_VH!5O^3Z````(/$
M(.G/_?__BT0D#(M0!(72#X0%_?__@^P,4HE4)!S_DYP```"#Q!"#^`,/ANO\
M__^#[`B-BZ6B__]1BU0D&(U$`OQ0_Y,,`0``@\00A<`/A<?\__^+5"0,B50D
M$.FZ_/__Z(43``"+A"3L````92L%%````'7K@^P,C8.JHO__4.BV]?__C;8`
M````55=64^BWY/__@</+@```@^P<9:$4````B40D##'`C7PD"(GZB[-\````
M98LN#[9%9(A%98V#LZ'__^B!Y?__A<!T"8`X,0^$9`$``.CO\/__98LNC8/C
MHO__:@-J`5!5_Y-(````B<6#Q!"%P'0J@^P$C8/EHO__4(M%#/\P9?\V_Y-,
M````BT4,BP"#Q!#V0`I`#X5'`0``C8/JHO__:@-J`5!E_S;_DT@```")Q8/$
M$(7`="J)^HV#@:'__^C]Y/__A<`/A/4```"#[`10BT4,_S!E_S;_DTP```"#
MQ!"#[`2-@^RB__]J`5!E_S;_DR````"-DP&C__^#Q`Q24&7_-O^33````&6+
M!HGZQD!E`(V#>*'__^BCY/__@\00B8,\`0``B<:%P'1$@^P(:,`!``!6_Y,8
M````C5`!@\00@_H!=@F#^!$/A:8```"+1"0,92L%%`````^%N0```(/$'%M>
M7UW#C;0F`````)"#[`S_LT`!``#H,O?__X/$$(F#/`$``(G&A<!UGXM$)`QE
M*P44````=7^#[`R-@Z"C__]0_Y/@````C;8`````@'@!``^$FO[__^F-_O__
MD(N#0`$``(L0BT4,BP#H+NG__^D)____C;0F`````&:0@^P(4&7_-O^3Q```
M`(/$$.FD_O__BU0D#&4K%10```!U%U"+@T`!``!6_S"-@\2C__]0_Y/@````
MZ$(1``!FD%=6Z,X```"!QJU^``!3@^P<9:$4````B40D&#'`BWPD+%?H>>W_
M_UI9:B]0B</_EE````"#Q!"%P'0#C5@!@^P,4_^6!`$``(G#C8;/H?__C50D
M&.A'X___@\00A<!T(`^V$(32#Y3`@/HP#Y3""-!U#H7_=`J`/P!U'8UT)@"0
MBT0D#&4K!10```!U/X/$$%M>7\.-="8`@^P$C8:2HO__:@104_^6\````(/$
M$(7`=<Z+1"0,92L%%````'4-@\00B?A;7E_I1.3__^AO$```BP0DPXLT),.+
M/"3#BRPDPV:09I!FD&:09I!FD&:0D%575E.)PX'L?`$``(E$)!"-3"0L9:$4
M````B80D;`$``#'`C70F`)"+5(,<#\J)%(&#P`&#^!!U[XM,)#"+="1@C50D
M-(ML)&2+1"1HB4PD"(V,)#0!``"+7"0LB4PD#.L*C;8`````B4PD"(L*B<>+
M0AB#P@0QR#'PB>Z)_3'8BUPD"-'`B4(T.50D#'79BWPD$(M$)"R+-XM7$(MO
M"(M?#(E4)!R-E`*9>8):B?"+3P3!P`6)]XE<)`@!PHGHB4PD%#'8B7PD#"'(
MP<D"B6PD&#'8BUPD,`'"B>@QR"'PBW0D"#'HC;0>F7F"6HM<)#0!QHG0P<`%
MC9P=F7F"6HML)#@!QHGXP<@"B<>)R#'X(=#!R@(QR(V,*9EY@EJ+;"0\`<.)
M\,'`!0'#B?@QT"'PP<X",?B-O"^9>8):BVPD0`'(B=G!P04!R(G1,?$AV3'1
MC90JF7F"6HML)$0!^8G'P<<%P<L"`?F)]S'?(<?!R`(Q]XVT+IEY@EJ+;"1(
M`?J)S\''!0'ZB<>)V#'X(<@QV(V<*YEY@EJ+;"1,`?")UL'&!0'PB<Z)^<'.
M`C'Q(=$Q^8V\+YEY@EJ+;"10`=F)P\'#!0'9B=.)\L'+`C':(<+!R`(Q\HVT
M+IEY@EJ+;"14`?J)S\''!0'ZB<>)V#'X(<@QV(V<*YEY@EJ+;"18`?")UL'&
M!0'PB<Z)^<'.`C'Q(=$Q^8V\+YEY@EJ+;"1<`=F)P\'#!0'9B=.)\L'+`C':
M(<+!R`(Q\HVT+IEY@EJ+;"1@`?J)S\''!0'ZB<>)V#'X(<@QV(V<*YEY@EJ+
M;"1D`?")UL'&!0'PB<Z)^<'.`C'Q(=$Q^8V\+YEY@EH!V8G#P<,%`=F)TXGR
MP<L",=HAPL'(`C'RB<6)V`'ZB<\QZ,''!2'(P<D"`?J+?"1H,=B-M#Z9>8):
MBWPD;`'PB=;!Q@6-O#N9>8):`?")[C'.B<,AUL'#!3'NP<H"`?>+="1P`=^)
MRS'3C;0UF7F"6HML)'0AP\'(`C'+C8PIF7F"6HML)'@!WHG[P<,%`=Z)TS'#
M(?LQT\'/`HV4*IEY@EH!RXGQP<$%`<N)P3'Y(?'!S@(QP0'1B=K!P@4!T8M4
M)'R-A!"AZ]ENB?HQ\C':P<L"`<*)R,'`!0'"BX0D@````(V\!Z'KV6Z)\#'8
M,<C!R0(!^(G7P<<%`?B)SXN,)(0```"-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'Q
MB=:+E"2(````P<X"C9P3H>O9;HGZ,?(QP@':B<O!R`+!PP4!VHG#BX0DC```
M`(V\!Z'KV6Z)\#'8,<C!R0(!^(G7P<<%`?B)SXN,))````"-M`ZAZ]ENB=DQ
M^3'1`?&)QL'&!0'QB=:+E"24````P<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!
MPP4!VHG#BX0DF````(V\!Z'KV6Z)\#'8,<C!R0(!^(G7P<<%`?B)SXN,))P`
M``"-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"2@````P<X"C9P3H>O9;HGZ
M,?(QPL'(`@':B<O!PP4!VHG#BX0DI````(V\!Z'KV6Z)\#'8,<C!R0(!^(G7
MP<<%`?B)SXN,)*@```"-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"2L````
MP<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#BX0DL````(V\!Z'KV6Z)
M\#'8,<C!R0(!^(G7P<<%`?B)SXN,)+0```"-M`ZAZ]ENB=DQ^3'1`?&)QL'&
M!0'QB=:+E"2X````P<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#BX0D
MO````(V\!Z'KV6Z)\#'8,<C!R0(!^(G7P<<%`?B)SXN,),````"-M`ZAZ]EN
MB=DQ^3'1`?&)QL'&!0'QB=:+E"3$````P<X"C9P3H>O9;HGZ,?(QPL'(`HG%
M`=J+A"3(````B<O!PP4!VHV<!Z'KV6Z)\#'H,<@!V(G3P<D"P<,%`=B)ZPG+
MB=^)ZR'7(<O!R@()^XN\),P```"-M#[<O!N/`?.)QL'&!0'SB<X)UHGWB<XA
MQR'6P<@""?Z+O"30````C;P]W+P;CP'WB=[!Q@4!]XG6"<:)]8G6(=TAQL'+
M`@GNBZPDU````(V,*=R\&X^)W8G#`<Z)^0GKP<$%(?L!SHG!(>D)V8N<)-@`
M``"-G!K<O!N/B?(!R\'/`HGIP<(%"?D!TXGJ(?'!S@(A^@G*BXPDW````(V,
M"-R\&X^)V`'1P<`%`<&)^`GPB<*)^"':(?#!RP()T(N4).````"-E!7<O!N/
M`<*)R,'`!0'"B?`)V(G%B?`AS2'8P<D"">B+K"3D````C;POW+P;CXG=`?B)
MUPG-P<<%(=4!^(G/B=DA^0GIBZPDZ````(VT+MR\&X^)_0'QB<;!Q@4!\8G6
MB?K!S@()]2'R(<7!R`()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)\`G8
MB<6)\"'-(=C!R0()Z(NL)/````"-O"_<O!N/B=T!^(G7"<W!QP4AU0'XB<^)
MV2'Y">F+K"3T````C;0NW+P;CXG]`?&)QL'&!0'QB=:)^L'.`@GU(?(AQ0GJ
MBZPD^````(V<*]R\&X\!VHG+P<@"P<,%`=J)PXGP"=B)Q8GP(<TAV,')`@GH
MBZPD_````(V\+]R\&X^)W0'XB=<)S<''!2'5`?B)SXG9(?D)Z8NL)``!``"-
MM"[<O!N/B?T!\8G&P<8%`?&)UHGZP<X""?4A\B'%P<@"">J+K"0$`0``C9PK
MW+P;CXG%`=J)R\'#!0':B?,)PXGP(<LAZ`G8BYPD"`$``(V<']R\&X\!V(G3
MP<D"P<,%`=B)ZPG+B=^)ZR'7(<O!R@()^XN\)`P!``"-M#[<O!N/`?.)QL'&
M!0'SB<X)UHGWB<XAQR'6P<@""?Z+O"00`0``C;P]W+P;CXG5`?Z)WPG%P<<%
M(=W!RP(!_HG7(<<)[XNL)!0!``"-C"G<O!N/B<4!^8GW"=W!QP4A]0'YB<<A
MWPGOBZPD&`$``(V4*MR\&X^+;"0,`=>)RL'.`L'"!0'7BY0D'`$``(V4$-;!
M8LJ)V#'P,<C!R0(!T(GZP<(%`="+E"0@`0``C9P3UL%BRHGR,<HQ^L'/`@':
MB</!PP4!VHN<)"0!``"-M![6P6+*B<LQ^S'#`?.)UL'&!0'SB<:+A"0H`0``
MP<X"C8P!UL%BRHGX,?`QT,'*`@'(B=G!P04!R(G1BY0D+`$``(V4%];!8LJ)
M]S'/,=\!UXG"P<(%`=>+E"0P`0``P<L"C;06UL%BRHG*,=HQP@'RB?[!Q@4!
M\HG&BX0D-`$``,'.`HV$`=;!8LJ)V3'Q,?G!SP(!P8G0P<`%`<&+A"0X`0``
MC9P#UL%BRHGP,?@QT`'8B<O!PP4!V(G3BY0D/`$``,'+`HV4%M;!8LJ)_C'>
M,<[!R0(!UHG"P<(%`=:+E"1``0``C;P7UL%BRHG:,<HQPL'(`@'ZB??!QP4!
M^HG'BX0D1`$``(V$`];!8LJ)RS'[,?/!S@(!PXG0P<`%`<.+A"1(`0``C8P!
MUL%BRHGX,?`QT,'*`@'(B=G!P04!R(G1BY0D3`$``(V4%];!8LJ)]S'/,=_!
MRP(!UXG"P<(%`=>+E"10`0``C;06UL%BRHG*,=HQP@'RB?[!Q@4!\HG&BX0D
M5`$``,'.`HV$`=;!8LJ)V3'Q,?G!SP(!P8G0P<`%`<&+A"18`0``C9P#UL%B
MRHGP,?@QT`'8B<O!PP4!V(G3BY0D7`$``,'+`HV4%M;!8LJ)_C'>,<[!R0(!
MUHG"P<(%`=:+E"1@`0``C;P7UL%BRHG:,<HQPL'(`@'ZB??!QP4!^HN\)&0!
M``"-O#O6P6+*B<LQPS'SP<X"`?N)U\''!0'[B[PD:`$``(V\/=;!8LH!SXG!
M,?$QT<'*`@'YB=_!QP4!^8M\)!")#XM,)!0!V8E/!(ML)!B+3"0(`>J)5PB-
M%#&)5PR+5"0<`=")1Q"+A"1L`0``92L%%````'4+@<1\`0``6UY?7</H<00`
M`)#H_//__P7?<0``@^P8:F#_D,````#'``$C16?'0`2)J\WOQT`(_MRZF,=`
M#'94,A#'0!#PX=+#QT`4`````,=`&`````#'0%P`````@\0<PU575NBM\___
M@<:,<0``4X/L'(M<)#"+1"0XBWPD-,'@`P-#%(M+&(UK'(E#%(M$)#B#T0#!
MZ!T!R(E#&(M#7(7`#X4Q`0``@WPD.#\/CGX!``"+1"0X@^A`B40D#,'H!HUP
M`8E$)`C!Y@8!_HUT)@"+!X/'0(E%`(M'Q(E%!(M'R(E%"(M'S(E%#(M'T(E%
M$(M'U(E%%(M'V(E%&(M'W(E%'(M'X(E%((M'Y(E%)(M'Z(E%*(M'[(E%+(M'
M\(E%,(M'](E%-(M'^(E%.(M'_(E%/(G8Z/?R__\Y]W63BT0D"(M4)`S!X`8I
MPHE4)#B#?"0X!')3BP:)Z8E#'(M$)#B+5"0XBT0&_(E$%?R-0R"#X/PIP2G.
M`TPD.(/A_(/Y!'(2@^'\,=*++!:)+!"#P@0YRG+SBT0D.(E#7(/$'%M>7UW#
MC70F`)"+1"0XA<!TY`^V!HA#'/9$)#@"=->+1"0XBTPD.`^W1`;^9HE$#?[K
MPXVT)@````"Z0````"G".U0D.'\[@^P$C6L<4@'HB50D$%=0_Y:8````BU0D
M&(M#7`'0@\00B4-<@_A`=8V)V"E4)#@!U^@5\O__Z8?^__^+5"0XZ[^-M"8`
M````C78`B?[I%____XVT)@````!FD.C,\?__!:]O``!55U93@^P<BUPD-(MT
M)#")1"0$BU,4BVL8C7L<B=#!Z@,/S8/B/P_(B40D"(U"`<9$$QR`@_@X#XX)
M`0``ND````"-#`<IPG0C,<#VP@%T#+@!````Q@$`.=!S$,8$`0#&1`$!`(/`
M`CG0<O")V.AS\?__C5<$QT,<`````#'`@^+\QT<T`````"G7C4\XB=?!Z0+S
MJXM$)`B):U2)0UB)V.A`\?__BP/!Z!B(!HL#P>@0B$8!BP.(9@*+`XA&`P^V
M0P>(1@0/MT,&B$8%BT,$B&8&BT,$B$8'#[9#"XA&"`^W0PJ(1@F+0PB(9@J+
M0PB(1@L/MD,/B$8,#[=##HA&#8M##(AF#HM##(A&#P^V0Q.(1A`/MT,2B$81
MBT,0B&82BT,0B$83BT0D!(E<)#"#Q!Q;7E]=_Z!@````C;0F`````(UV`+HX
M````*<(!^(/Z!`^"C@```(U(!,<``````(/A_,=$$/P`````*<@!T(/@_(/X
M!`^"&?___XG'N@0```"#Y_R)?"0,C7C_P>\"QP$`````@^<!.<(/@_3^__^%
M_W08QT$$`````(M$)`RZ"````#G"#X/8_O__BT0D#,<$$0````#'1!$$````
M`(/""#G"<NKIN?[__XVT)@````"-=@"%T@^$I_[__\8``/;"`@^$F_[__S')
M9HE,$/[IC_[__^B\[___!9]M``"#[`S_L"`!``#_="0<_W0D'/]T)!S_D$``
M``"#Q!S#9I!FD&:0D%9>Z(KO__\%;6T``(/L#/^0R````````%.#[`CH/]'_
M_X'#4VT``(/$"%O#````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U
M.0`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[&`$``"(```"P
M?___8`$``-!___^H#```,(+__S0!``!@@___A`$``$"$___\`0``T(3__T@"
M``!0AO___`(``*"(__]\`P``<(G__PP$``#0B?__7`0``!"*__^`!```X(K_
M_Q@%``#PBO__+`4``""-__\L!@``8(W__V`&``#@CO__Y`8``."2__\D!P``
M4)/__T`'``"0D___:`<``""5__\8"```4)7__T0(``!0EO__R`@``*"=__]D
M"P``P)___S0,``"1H/__\`P``)6@__\$#0``F:#__Q@-``"=H/__+`T``+"@
M__]`#0``D*S__X0-``#@K/__H`T``,"N___P#0``T+#__S`.````L?__5`X`
M`!0``````````7I2``%\"`$;#`0$B`$'"!`````<````](#__RP`````````
M%``````````!>E(``7P(`1L,!`2(`0``(````!P```!(?O__(``````."$8.
M#$H/"W0$>``_&CLJ,B0B=````$````#4@?__W`````!!#@B%`DP.#(<#00X0
MA@1!#A2#!4,.,`))#C1!#CA$#CQ!#D!)#C!9"@X40\,.$$'&#@Q!QPX(0<4.
M!$<+=`H.%$/##A!!Q@X,0<<."$'%#@1&"T,.%$7##A!!Q@X,0<<."$'%#@0`
M2````+@````\@O__@@````!!#@B&`DP.#(,#10Z(`5$.C`%!#I`!20Z``6$.
MB`%"#HP!00Z0`4D.@`%@"@X,0<,."$'&#@1!"P```+`````$`0``@(+__WX!
M````00X(A0)!#@R'`T$.$(8$3`X4@P5(#J`!;`H.%$'##A!!Q@X,0<<."$'%
M#@1)"T,.K`%!#K`!2PZ@`4<.K`%!#K`!20Z@`7$.K`%!#K`!:0ZL`4<.J`%%
M#JP!00ZP`4$.M`%"#K@!0@Z\`4$.P`%)#J@!10ZL`4$.L`%)#J`!6`ZL`4$.
ML`%)#J`!0PZL`4$.L`%)#J`!3@ZL`4$.L`%2#J`!`'P```"X`0``3(/__T@"
M````00X(A0),#@R'`T,.$(8$00X4@P5%#DQ7#E!)#D!:#DQ##E!-#D`"5`Y,
M2PY02PY``FD*#A1!PPX00<8.#$''#@A!Q0X$20L"9`Y,00Y050Y`4@Y$10Y(
M10Y,00Y050Y`5PY(00Y,00Y03PY`````C````#@"```<A?__T`````!!#@B%
M`D$.#(<#00X0A@1!#A2#!48.E"!'#L0@90[(($L.S"!!#M`@20[`(%T.Q"!$
M#L@@00[,($,.T"!)#L`@5@H.%$'##A!!Q@X,0<<."$'%#@1%"TL.Q"!!#L@@
M0@[,($$.T"!)#L`@2P[$($$.R"!!#LP@0P[0($D.P"``3````,@"``!<A?__
M7`````!!#@B&`D$.#(,#3@X030X43`X800X<0PX@1PX<1PX80@X<00X@00XD
M1PXH1PXL0PXP20X,0<,."$'&#@0````@````&`,``&R%__\T`````$T.$$<.
M%$P.&$$.'$D.($D.!`"4````/`,``(B%___-`````$$."(4"00X,AP-!#A"&
M!$$.%(,%1@Z4($H.E$!'#K!`90ZX0$<.O$!!#L!`1P[$0$4.R$!"#LQ`10[0
M0$D.M$!%#KA`2`Z\0$$.P$!)#K!`1PZ\0$8.P$!+#K!`1PZT0$$.N$!!#KQ`
M00[`0$X.L$!6"@X40\,.$$'&#@Q!QPX(0<4.!$$+`!````#4`P``P(7__P4`
M````````_````.@#``"\A?__)P(```!!#@B%`D$.#(<#00X0A@1!#A2#!48.
ME"!*#K`A`D`.N"%"#KPA0P[`(4D.L"%M"@X40<,.$$'&#@Q!QPX(0<4.!$4+
M0PZ\(4$.P"%'#KPA00ZX(4L.O"%!#L`A5PZP(6`.N"%!#KPA00[`(4D.L"%+
M#KPA00[`(4\.L"%=#KPA00[`(4L.L"%'#KPA00[`(5$.L"%.#K0A00ZX(40.
MO"%!#L`A1`[$(44.R"%"#LPA2`[0(4D.N"%$#KPA00[`(4D.L"%7#K@A1`Z\
M(4(.P"%+#K`A?@ZX(4(.O"%!#L`A20ZP(50.O"%!#L`A20ZP(3````#H!```
M[(;__S@`````00X(A@),#@R#`T,.&$8.'$$.($D.$$X.#$/##@A!Q@X$``"`
M````'`4``/B&__]T`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($<.L"!U
M#KP@00[`($P.L"!_#K@@0@Z\($$.P"!)#K`@3PZ\($$.P"!)#K`@6@H.%$'#
M#A!!Q@X,0<<."$'%#@1+"V,*#A1#PPX00<8.#$''#@A!Q0X$1PL````\````
MH`4``/2'___\`P```$$."(4"00X,AP-!#A"&!$P.%(,%0PY``[@#"@X41\,.
M$$'&#@Q!QPX(0<4.!$4+&````.`%``"TB___80````!-#B`"1@H.!$4+`"0`
M``#\!0``"(S__S4`````00X(@P).#A!%#A1$#AA(#AQ"#B````"L````)`8`
M`"",__^+`0```$$."(4"00X,AP-!#A"&!$$.%(,%1PP#E(`$3@T$0P[`@`1B
M#L2`!$(.R(`$0@[,@`1!#M"`!'T.P(`$4@[$@`1!#LB`!$$.S(`$1`[0@`1+
M#L"`!$P.Q(`$10[(@`1!#LR`!$0.T(`$20[`@`0"5`H.%$'##A!!Q@X,0<<.
M"$'%#@1&"WL*#LR`!$<.T(`$10M3"@[,@`1'#M"`!$4+`"@```#4!@```(W_
M_RT`````00X(@P).#A!)#AQ!#B!)#A!)#@A!PPX$````@``````'```$C?__
M^0````!!#@B%`D$.#(<#00X0A@1,#A2#!4,.0`)""@X40\,.$$'&#@Q!QPX(
M0<4.!$8+0PY(00Y,00Y020Y`5`H.%$'##A!!Q@X,0<<."$'%#@1*"T,.3$$.
M4&<.1$D.2$$.3$<.4$$.5$(.6$(.7$$.8$T.0```F`(``(0'``"`C?__2@<`
M``!!#@B%`D$.#(<#00X0A@1!#A2#!5$.D`("T`Z<`D$.H`))#I`"50Z<`D$.
MH`)-#I`"0PZ<`D$.H`)/#I`"7@Z<`D<.H`)!#J0"0@ZH`D(.K`)!#K`"4`Z0
M`@)(#IP"00Z@`DL.D`)_#IP"00Z@`D<.G`)$#J`":`ZD`D$.J`)+#JP"1PZP
M`D,.M`)"#K@"0@Z\`D$.P`))#I@"10Z<`D$.H`))#I`"60Z8`D$.G`)$#J`"
M2PZ0`D<.G`)$#J`"1@ZD`D<.J`)*#JP"0@ZP`DD.D`):"@X40\,.$$'&#@Q!
MQPX(0<4.!$@+0PZ<`D0.H`)+#I`"`ED.G`)!#J`"6`Z0`DL.F`)!#IP"1@Z@
M`DP.D`)+#IP"1`Z@`DL.D`)(#I@"1PZ<`DT.H`))#I`"`FL.E`)!#I@"2@Z<
M`D0.H`)!#J0"0@ZH`D(.K`)!#K`"3PZ0`E\.G`)!#J`"00ZD`D$.J`)$#JP"
M1`ZP`D0.M`)"#K@"0@Z\`D$.P`))#I`"0PZ8`D4.G`)!#J`"20Z0`D@.G`)$
M#J`"7`Z0`@)'#IP"2`Z@`DL.D`);#IP"00Z@`DL.D`),"@Z8`D$.G`)$#J`"
M1@ZD`E(+0PZ<`D$.H`)(#I`"80H.%$/##A!!Q@X,0<<."$'%#@1-"UL.F`)"
M#IP"1`Z@`DD.D`)F#I0"1`Z8`D$.G`)%#J`"30Z4`D(.F`)(#IP"10Z@`DT.
MD`)P#I0"3PZ8`D$.G`)!#J`"30Z4`D(.F`)(#IP"10Z@`DD.D`)8#I0"1PZ8
M`D0.G`)$#J`"00ZD`D(.J`)"#JP"00ZP`DD.D`)7#IP"00Z@`DT.D`),#I@"
M1PZ<`DD.H`))#I`";0Z<`D<.H`(```#,````(`H``#22__\>`@```$$."(4"
M00X,AP-!#A"&!$$.%(,%3@XP`DH.-$(..$$./$$.0$L.,$<.-$<..$4./$,.
M0$X.,%(.-$(..$$./$,.0$L.,%P.-$$..$4./$,.0$D.,$,.-$@..$$./$,.
M0$\.-$$..$$./$,.0%T.,$\..$4./$$.0$P.,&(*#A1!PPX00<8.#$''#@A!
MQ0X$20M#"@X\1@Y`2`XP7`X\1PY`3`MS#CA!#CQ##D!)#C!3"@XT1PXX0@X\
M1PY`1@L`<````/`*``"$D___T0````!!#@B'`D$.#(8#3`X0@P1##BQ1#C!&
M#BQ!#BA"#BQ!#C!+#B!*#BQ!#C!:#B!T"@X00<,.#$'&#@A!QPX$10M##B1(
M#BA!#BQ!#C!)#B!4"@X00\,.#$'&#@A!QPX$10L```!$````9`L``"!S__]5
M`@```$0,`0!)$`4"=0!!$`<"=7Q$$`8"=7@0`P)U=$P/`W5P!@-O`0K!#`$`
M0<-!QD''0<5##`0$00L0````K`L``)F3__\$`````````!````#`"P``B9/_
M_P0`````````$````-0+``!YD___!``````````0````Z`L``&F3__\$````
M`````$````#\"P``:)/__]\+````00X(A0)!#@R'`T$.$(8$00X4@P5(#I`#
M`\D+"@X40<,.$$'&#@Q!QPX(0<4.!$$+````&````$`,```$G___4`````!-
M#AQ"#B`"0`X$`$P```!<#```.)___]<!````00X(A0)!#@R'`T$.$(8$3`X4
M@P5##C`#+`$*#A1!PPX00<8.#$''#@A!Q0X$1@L"0`XT1`XX1PX\00Y`4@XP
M/````*P,``#(H/__$`(```!+#@B%`D$.#(<#00X0A@1!#A2#!4,.,`,K`0H.
M%$'##A!!Q@X,0<<."$'%#@10"R````#L#```F*+__RD`````30X01@X41`X8
M1`X<1`X@20X$`!@````0#0``I*+__Q4`````00X(00X$30X0````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#`(P``
M<",```$```#Z`@```0````4#```=````F00```P`````(```#0```(A1```9
M````U+T``!L````$````&@```-B]```<````!````/7^_V\T`@``!0```'P)
M```&````?`,```H```"\!```"P```!`````5``````````,```#DO@```@``
M``@````4````$0```!<```#0$0``$0```)@/```2````.`(``!,````(````
M'@````@```#[__]O`0``"/[__V_X#@``____;P$```#P__]O.`X``/K__V\%
M`````````````````````````````````````````````````````````-R]
M`````````````#8@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`(`````````3````*4$%2+G!M"@````#L8@``1T-#.B`H1TY5
M*2`Q,RXR+C$@,C`R,S`X,#$``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M```````````````````````````````````````````````````````+````
M`0````(```"T`0``M`$``!,```````````````$`````````$P````<````"
M````R`$``,@!```D```````````````$`````````"8````'`````@```.P!
M``#L`0``*```````````````!``````````Y````!P````(````4`@``%`(`
M`"````````````````0`````````1P```/;__V\"````-`(``#0"``!(`0``
M!@`````````$````!````%$````+`````@```'P#``!\`P````8```<````!
M````!````!````!9`````P````(```!\"0``?`D``+P$``````````````$`
M````````80```/___V\"````.`X``#@.``#`````!@`````````"`````@``
M`&X```#^__]O`@```/@.``#X#@``H`````<````!````!`````````!]````
M"0````(```"8#P``F`\``#@"```&``````````0````(````A@````D```!"
M````T!$``-`1```(````!@```!8````$````"````(\````!````!@`````@
M````(```(```````````````!`````````"*`````0````8````@(```("``
M`"```````````````!`````$````E0````$````&````0"```$`@``!%,0``
M```````````0`````````)L````!````!@```(A1``"(40``%```````````
M````!`````````"A`````0````(`````8````&```&Y```````````````0`
M````````J0````$````"````<*```'"@```<`0`````````````$````````
M`+<````!`````@```(RA``",H0``6`T`````````````!`````````#!````
M#@````,```#4O0``U+T```0```````````````0````$````S0````\````#
M````V+T``-B]```$```````````````$````!````-D````&`````P```-R]
M``#<O0``"`$```<`````````!`````@```#B`````0````,```#DO@``Y+X`
M`!P!``````````````0````$````YP````$````#`````,````#````8````
M```````````$`````````.T````(`````P```!C````8P```%```````````
M````!`````````#R`````0```#``````````&,```!L```````````````$`
M```!`````0````,``````````````#/```#[```````````````!````````
!````
